var Spinner = require('spin.js');

module.exports = function(jQuery) {
  'use strict';
  var $ = jQuery;

  jQuery.fn.spinjax = function(passed) {
    var defaults = {
      spinner: defaultSpinner(),
      disable: true,
      preventDefault: true,
      also: function($form) {
        $form.css({'opacity': '0.5'});
      }
    };
    var options = $.extend({}, defaults, passed); 

    this.submit(function(event) {
      if (options.preventDefault)
        event.preventDefault();

      if (options.disable)
        disableAll(this);

      if (options.also !== false)
        options.also(this);

      options.spinner.spin(event.target);

    }.bind(this));

    this.spinjaxReset = function() {
      this.removeAttr('style');
      options.spinner.stop();
      enableAll(this);
    }.bind(this);

    return this;
  };

  function disableAll($element) {
    var $elements = $element
      .find('input, textarea, select, button')
      .attr('disabled', 'true')
      .addClass('disabled');
  }

  function enableAll($element) {
    var $elements = $element
      .find('input, textarea, select, button')
      .removeAttr('disabled')
      .removeClass('disabled');
  }

  function defaultSpinner() {
    var opts = {
      lines: 13 // The number of lines to draw
    , length: 28 // The length of each line
    , width: 14 // The line thickness
    , radius: 42 // The radius of the inner circle
    , scale: 1 // Scales overall size of the spinner
    , corners: 1 // Corner roundness (0..1)
    , color: '#000' // #rgb or #rrggbb or array of colors
    , opacity: 0.25 // Opacity of the lines
    , rotate: 0 // The rotation offset
    , direction: 1 // 1: clockwise, -1: counterclockwise
    , speed: 1 // Rounds per second
    , trail: 60 // Afterglow percentage
    , fps: 20 // Frames per second when using setTimeout() as a fallback for CSS
    , zIndex: 2e9 // The z-index (defaults to 2000000000)
    , className: 'spinner' // The CSS class to assign to the spinner
    , top: '50%' // Top position relative to parent
    , left: '50%' // Left position relative to parent
    , shadow: false // Whether to render a shadow
    , hwaccel: false // Whether to use hardware acceleration
    , position: 'absolute' // Element positioning
    }

    return new Spinner(opts);
  }

}
